@@ -2,16 +2,20 @@
 '''
 Return config information
 '''
-from __future__ import absolute_import
 
 # Import python libs
+from __future__ import absolute_import, print_function
 import re
 import os
 
 # Import salt libs
-import salt.utils
+import salt.utils.data
+import salt.utils.files
 import salt.syspaths as syspaths
 
+# Import 3rd-party libs
+from salt.ext import six
+
 # Set up the default values for all systems
 DEFAULTS = {'mongo.db': 'salt',
             'mongo.host': 'salt',
@@ -31,7 +35,7 @@ DEFAULTS = {'mongo.db': 'salt',
             'solr.request_timeout': None,
             'solr.init_script': '/etc/rc.d/solr',
             'solr.dih.import_options': {'clean': False, 'optimize': True,
-                                        'commit': True, 'verbose': False},
+                                         'commit': True, 'verbose': False},
             'solr.backup_path': None,
             'solr.num_backups': 1,
             'poudriere.config': '/usr/local/etc/poudriere.conf',
@@ -45,8 +49,8 @@ DEFAULTS = {'mongo.db': 'salt',
             'ldap.bindpw': '',
             'hosts.file': '/etc/hosts',
             'aliases.file': '/etc/aliases',
-            'virt.images': os.path.join(syspaths.SRV_ROOT_DIR, 'salt-images'),
-            'virt.tunnel': False,
+            'virt': {'tunnel': False,
+                     'images': os.path.join(syspaths.SRV_ROOT_DIR, 'salt-images')},
             }
 
 
@@ -75,12 +79,10 @@ def manage_mode(mode):
 
         salt '*' config.manage_mode
     '''
-    if mode is None:
-        return None
-    ret = str(mode).lstrip('0').zfill(4)
-    if ret[0] != '0':
-        return '0{0}'.format(ret)
-    return ret
+    # config.manage_mode should no longer be invoked from the __salt__ dunder
+    # in Salt code, this function is only being left here for backwards
+    # compatibility.
+    return salt.utils.files.normalize_mode(mode)
 
 
 def valid_fileproto(uri):
@@ -96,7 +98,7 @@ def valid_fileproto(uri):
     '''
     try:
         return bool(re.match('^(?:salt|https?|ftp)://', uri))
-    except Exception:
+    except Exception:  # pylint: disable=broad-except
         return False
 
 
@@ -150,14 +152,14 @@ def merge(value,
     if not omit_opts:
         if value in __opts__:
             ret = __opts__[value]
-            if isinstance(ret, str):
+            if isinstance(ret, six.string_types):
                 return ret
     if not omit_master:
         if value in __pillar__.get('master', {}):
             tmp = __pillar__['master'][value]
             if ret is None:
                 ret = tmp
-                if isinstance(ret, str):
+                if isinstance(ret, six.string_types):
                     return ret
             elif isinstance(ret, dict) and isinstance(tmp, dict):
                 tmp.update(ret)
@@ -170,7 +172,7 @@ def merge(value,
             tmp = __pillar__[value]
             if ret is None:
                 ret = tmp
-                if isinstance(ret, str):
+                if isinstance(ret, six.string_types):
                     return ret
             elif isinstance(ret, dict) and isinstance(tmp, dict):
                 tmp.update(ret)
@@ -214,16 +216,16 @@ def get(key, default=''):
 
         salt '*' config.get pkg:apache
     '''
-    ret = salt.utils.traverse_dict_and_list(__opts__, key, '_|-')
+    ret = salt.utils.data.traverse_dict_and_list(__opts__, key, '_|-')
     if ret != '_|-':
         return ret
-    ret = salt.utils.traverse_dict_and_list(__grains__, key, '_|-')
+    ret = salt.utils.data.traverse_dict_and_list(__grains__, key, '_|-')
     if ret != '_|-':
         return ret
-    ret = salt.utils.traverse_dict_and_list(__pillar__, key, '_|-')
+    ret = salt.utils.data.traverse_dict_and_list(__pillar__, key, '_|-')
     if ret != '_|-':
         return ret
-    ret = salt.utils.traverse_dict_and_list(__pillar__.get('master', {}), key, '_|-')
+    ret = salt.utils.data.traverse_dict_and_list(__pillar__.get('master', {}), key, '_|-')
     if ret != '_|-':
         return ret
     return default
@@ -241,10 +243,10 @@ def dot_vals(value):
         salt '*' config.dot_vals host
     '''
     ret = {}
-    for key, val in __pillar__.get('master', {}).items():
+    for key, val in six.iteritems(__pillar__.get('master', {})):
         if key.startswith('{0}.'.format(value)):
             ret[key] = val
-    for key, val in __opts__.items():
+    for key, val in six.iteritems(__opts__):
         if key.startswith('{0}.'.format(value)):
             ret[key] = val
     return ret
