@@ -125,12 +125,53 @@ class NetapiClientTest(TestCase):
     def test_wheel_async(self):
         # Give this test a little breathing room
         time.sleep(3)
-        low = {'client': 'wheel_async', 'fun': 'key.list_all'}
-        low.update(self.eauth_creds)
+        timeout = 60
+        opts = salt.config.master_config(os.path.join(RUNTIME_VARS.TMP_CONF_DIR, 'master'))
+        with salt.utils.event.get_event("master", opts=opts) as event:
+            low = {"client": "wheel_async", "fun": "key.list_all"}
+            low.update(self.eauth_creds)
 
-        ret = self.netapi.run(low)
-        self.assertIn('jid', ret)
-        self.assertIn('tag', ret)
+            ret = self.netapi.run(low)
+            self.assertIn("jid", ret)
+            self.assertIn("tag", ret)
+            jid = ret['jid']
+            start = time.time()
+            found_return = False
+            while time.time() - start <= timeout:
+                evt = event.get_event(tag=ret['tag'])
+                if evt is None:
+                    continue
+                assert 'error' not in evt
+                if 'return' in evt:
+                    found_return = True
+                    assert evt['success'] is True
+                    break
+            assert found_return is True
+
+    def test_wheel_async_unauthenticated(self):
+        """
+        This is a test for CVE-2021-25281
+        """
+        # Give this test a little breathing room
+        time.sleep(3)
+        opts = salt.config.master_config(os.path.join(RUNTIME_VARS.TMP_CONF_DIR, 'master'))
+        with salt.utils.event.get_event("master", opts=opts) as event:
+            low = {"client": "wheel_async", "fun": "key.list_all"}
+            low.update({
+                "eauth": "pam",
+                "username": "notvalid",
+                "password": "notvalid",
+            })
+            ret = self.netapi.run(low)
+            self.assertIn("jid", ret)
+            self.assertIn("tag", ret)
+            jid = ret['jid']
+            evt = event.get_event(tag=ret['tag'])
+            assert 'error' in evt
+            assert evt['error'] == {
+                'name': 'EauthAuthenticationError',
+                'message': 'Authentication failure of type "eauth" occurred for user notvalid.'
+            }
 
     def test_wheel_unauthenticated(self):
         low = {'client': 'wheel', 'tgt': '*', 'fun': 'test.ping'}
@@ -445,8 +486,14 @@ class NetapiSSHClientAuthTest(SSHCase, ModuleCase):
         except AssertionError:
             ModuleCase.run_function(self, "user.delete", [self.USERA], remove=True)
             self.skipTest("Could not add user or password, skipping test")
+        self.expfile = os.path.join(RUNTIME_VARS.TMP, "exploited")
 
     def tearDown(self):
+        try:
+            os.remove(self.expfile)
+        except OSError:
+            pass
+        del self.expfile
         del self.netapi
         ModuleCase.run_function(self, "user.delete", [self.USERA], remove=True)
 
@@ -462,6 +509,36 @@ class NetapiSSHClientAuthTest(SSHCase, ModuleCase):
         cls.post_webserver.stop()
         del cls.post_webserver
 
+    @staticmethod
+    def cleanup_file(path):
+        try:
+            os.remove(path)
+        except OSError:
+            pass
+
+    def test_extra_mods(self):
+        """
+        validate input from extra_mods
+        """
+        path = os.path.join(RUNTIME_VARS.TMP, "test_extra_mods")
+        self.addCleanup(self.cleanup_file, path)
+        low = {
+            "client": "ssh",
+            "tgt": "localhost",
+            "fun": "test.ping",
+            "roster_file": "roster",
+            "rosters": [self.rosters],
+            "ssh_priv": self.priv_file,
+            "eauth": "pam",
+            "username": self.USERA,
+            "password": self.USERA_PWD,
+            "regen_thin": True,
+            "thin_extra_mods": "';touch {0};'".format(path)
+        }
+
+        ret = self.netapi.run(low)
+        self.assertFalse(os.path.exists(path))
+
     def test_ssh_auth_bypass(self):
         """
         CVE-2020-25592 - Bogus eauth raises exception.
@@ -558,3 +635,35 @@ class NetapiSSHClientAuthTest(SSHCase, ModuleCase):
         ret = self.netapi.run(low)
         assert "localhost" in ret
         assert ret["localhost"]["return"] is True
+
+    def test_ssh_cve_2021_3197_a(self):
+        assert not os.path.exists(self.expfile)
+        low = {
+            "eauth": "auto",
+            "username": self.USERA,
+            "password": self.USERA_PWD,
+            "client": "ssh",
+            "tgt": "localhost",
+            "fun": "test.ping",
+            "ssh_port": '22 -o ProxyCommand="touch {}"'.format(self.expfile),
+            "ssh_priv": self.priv_file,
+        }
+        ret = self.netapi.run(low)
+        assert not os.path.exists(self.expfile)
+
+    def test_ssh_cve_2021_3197_b(self):
+        assert not os.path.exists(self.expfile)
+        low = {
+            "eauth": "auto",
+            "username": self.USERA,
+            "password": self.USERA_PWD,
+            "client": "ssh",
+            "tgt": "localhost",
+            "fun": "test.ping",
+            "ssh_port": 22,
+            "ssh_priv": self.priv_file,
+            'ssh_options': ['ProxyCommand="touch {}"'.format(self.expfile),]
+        }
+        ret = self.netapi.run(low)
+        assert not os.path.exists(self.expfile)
+
